# Question about git-cherry and the rev list it's using

6 messages from 2011-05-11 to 2011-05-13. Participants: Francis Moreau, Michael J Gruber.
Thread: https://gitlist.dev/t/27324

## Francis Moreau, 2011-05-11 16:11

Subject: Question about git-cherry and the rev list it's using
Message-ID: <BANLkTinMfVE=s+TouyxE-ucf7MHGf1m7HA@mail.gmail.com>
URL: https://gitlist.dev/e/BANLkTinMfVE%3Ds%2BTouyxE-ucf7MHGf1m7HA%40mail.gmail.com

```
Hello,

I'm using "git cherry old master base" to see if all commits between
master and base have been applied in my 'old' branch.

So I expect that git cherry is using a list of commits given by : "git
rev-list --no-merges base..master".

But it looks like it's not the case:

  $ git rev-list --no-merges --oneline base..master | wc -l
  22

  $ git cherry old master base | wc -l
  12

Could anybody help me on this because I don't understand the results I have ?

Thanks
-- 
Francis

```

## Michael J Gruber, 2011-05-12 06:47

Subject: Re: Question about git-cherry and the rev list it's using
Message-ID: <4DCB826F.5020406@drmicha.warpmail.net>
URL: https://gitlist.dev/e/4DCB826F.5020406%40drmicha.warpmail.net
In-Reply-To: <BANLkTinMfVE=s+TouyxE-ucf7MHGf1m7HA@mail.gmail.com>

```
Francis Moreau venit, vidit, dixit 11.05.2011 18:11:
> Hello,
> 
> I'm using "git cherry old master base" to see if all commits between
> master and base have been applied in my 'old' branch.
> 
> So I expect that git cherry is using a list of commits given by : "git
> rev-list --no-merges base..master".

Not really.

For each commit in "--no-merges old..master ^base" (i.e. "--no-merges
master ^old ^base"), "git cherry" checks whether there is a patch
equivalent commit in "--no-merges master..old", and outputs it with + or -.

> But it looks like it's not the case:
> 
>   $ git rev-list --no-merges --oneline base..master | wc -l
>   22
> 
>   $ git cherry old master base | wc -l
>   12
> 
> Could anybody help me on this because I don't understand the results I have ?

"--no-merges ^old ^base" should rev-list --count to 12.

But you may be better off with something like

git rev-list --count --cherry master...old ^base

(untested)

Michael

```

## Francis Moreau, 2011-05-13 06:54

Subject: Re: Question about git-cherry and the rev list it's using
Message-ID: <BANLkTi=qRbpBG_PDPjO_TVEe+nWqrFQ28w@mail.gmail.com>
URL: https://gitlist.dev/e/BANLkTi%3DqRbpBG_PDPjO_TVEe%2BnWqrFQ28w%40mail.gmail.com
In-Reply-To: <4DCB826F.5020406@drmicha.warpmail.net>

```
[ resending to the mailing list too ]

On Thu, May 12, 2011 at 8:47 AM, Michael J Gruber
<git@drmicha.warpmail.net> wrote:
> Francis Moreau venit, vidit, dixit 11.05.2011 18:11:
>> Hello,
>>
>> I'm using "git cherry old master base" to see if all commits between
>> master and base have been applied in my 'old' branch.
>>
>> So I expect that git cherry is using a list of commits given by : "git
>> rev-list --no-merges base..master".
>
> Not really.
>
> For each commit in "--no-merges old..master ^base" (i.e. "--no-merges
> master ^old ^base"), "git cherry" checks whether there is a patch
> equivalent commit in "--no-merges master..old", and outputs it with + or -.
>

oh you're right, I missed the case when old has been merged in master.

Thanks !
-- 
Francis

```

## Francis Moreau, 2011-05-13 07:02

Subject: Re: Question about git-cherry and the rev list it's using
Message-ID: <BANLkTi=d+gDhgnmOzUDfHhGJP76JuLHJ2Q@mail.gmail.com>
URL: https://gitlist.dev/e/BANLkTi%3Dd%2BgDhgnmOzUDfHhGJP76JuLHJ2Q%40mail.gmail.com
In-Reply-To: <BANLkTi=qRbpBG_PDPjO_TVEe+nWqrFQ28w@mail.gmail.com>

```
On Fri, May 13, 2011 at 8:54 AM, Francis Moreau <francis.moro@gmail.com> wrote:
> [ resending to the mailing list too ]
>
> On Thu, May 12, 2011 at 8:47 AM, Michael J Gruber
> <git@drmicha.warpmail.net> wrote:
>> Francis Moreau venit, vidit, dixit 11.05.2011 18:11:
>>> Hello,
>>>
>>> I'm using "git cherry old master base" to see if all commits between
>>> master and base have been applied in my 'old' branch.
>>>
>>> So I expect that git cherry is using a list of commits given by : "git
>>> rev-list --no-merges base..master".
>>
>> Not really.
>>
>> For each commit in "--no-merges old..master ^base" (i.e. "--no-merges
>> master ^old ^base"), "git cherry" checks whether there is a patch
>> equivalent commit in "--no-merges master..old", and outputs it with + or -.
>>
>
> oh you're right, I missed the case when old has been merged in master.
>

BTW, can't it be convenient for users if git-cherry also displays the
sha1 of the commits which have been merged upstream (the ones with the
'-' sign) ?

Thanks
-- 
Francis

```

## Michael J Gruber, 2011-05-13 11:13

Subject: Re: Question about git-cherry and the rev list it's using
Message-ID: <4DCD1254.4050008@drmicha.warpmail.net>
URL: https://gitlist.dev/e/4DCD1254.4050008%40drmicha.warpmail.net
In-Reply-To: <BANLkTi=d+gDhgnmOzUDfHhGJP76JuLHJ2Q@mail.gmail.com>

```
Francis Moreau venit, vidit, dixit 13.05.2011 09:02:
> On Fri, May 13, 2011 at 8:54 AM, Francis Moreau <francis.moro@gmail.com> wrote:
>> [ resending to the mailing list too ]
>>
>> On Thu, May 12, 2011 at 8:47 AM, Michael J Gruber
>> <git@drmicha.warpmail.net> wrote:
>>> Francis Moreau venit, vidit, dixit 11.05.2011 18:11:
>>>> Hello,
>>>>
>>>> I'm using "git cherry old master base" to see if all commits between
>>>> master and base have been applied in my 'old' branch.
>>>>
>>>> So I expect that git cherry is using a list of commits given by : "git
>>>> rev-list --no-merges base..master".
>>>
>>> Not really.
>>>
>>> For each commit in "--no-merges old..master ^base" (i.e. "--no-merges
>>> master ^old ^base"), "git cherry" checks whether there is a patch
>>> equivalent commit in "--no-merges master..old", and outputs it with + or -.
>>>
>>
>> oh you're right, I missed the case when old has been merged in master.
>>
> 
> BTW, can't it be convenient for users if git-cherry also displays the
> sha1 of the commits which have been merged upstream (the ones with the
> '-' sign) ?

(I assume you mean the sha1 of the commit as it is in upstream.)

Well, in general the map "sha1 to patchid" is not one-to-one and may not
even be two-to-one. So we possibly would have to list more than one sha1
along with the -1. Anyways, with the current implementation you can't do
that, and it is not simple to change (because we may traverse *a lot* of
commits if base and upstream are far apart or disconnected).

Note that "git cherry -v" gives you the subjects so that you can grep
for those in case they match in your work flow. Same with "git log
--cherry --oneline" etc..

Michael

```

## Francis Moreau, 2011-05-13 16:29

Subject: Re: Question about git-cherry and the rev list it's using
Message-ID: <BANLkTik4Gt8y0kSBcMrROTd67dfxMXO-KA@mail.gmail.com>
URL: https://gitlist.dev/e/BANLkTik4Gt8y0kSBcMrROTd67dfxMXO-KA%40mail.gmail.com
In-Reply-To: <4DCD1254.4050008@drmicha.warpmail.net>

```
On Fri, May 13, 2011 at 1:13 PM, Michael J Gruber
<git@drmicha.warpmail.net> wrote:
> Francis Moreau venit, vidit, dixit 13.05.2011 09:02:
>> On Fri, May 13, 2011 at 8:54 AM, Francis Moreau <francis.moro@gmail.com> wrote:
>>> [ resending to the mailing list too ]
>>>
>>> On Thu, May 12, 2011 at 8:47 AM, Michael J Gruber
>>> <git@drmicha.warpmail.net> wrote:
>>>> Francis Moreau venit, vidit, dixit 11.05.2011 18:11:
>>>>> Hello,
>>>>>
>>>>> I'm using "git cherry old master base" to see if all commits between
>>>>> master and base have been applied in my 'old' branch.
>>>>>
>>>>> So I expect that git cherry is using a list of commits given by : "git
>>>>> rev-list --no-merges base..master".
>>>>
>>>> Not really.
>>>>
>>>> For each commit in "--no-merges old..master ^base" (i.e. "--no-merges
>>>> master ^old ^base"), "git cherry" checks whether there is a patch
>>>> equivalent commit in "--no-merges master..old", and outputs it with + or -.
>>>>
>>>
>>> oh you're right, I missed the case when old has been merged in master.
>>>
>>
>> BTW, can't it be convenient for users if git-cherry also displays the
>> sha1 of the commits which have been merged upstream (the ones with the
>> '-' sign) ?
>
> (I assume you mean the sha1 of the commit as it is in upstream.)

yes.

>
> Well, in general the map "sha1 to patchid" is not one-to-one and may not
> even be two-to-one. So we possibly would have to list more than one sha1
> along with the -1.

just showing the latest one would be nice though.

> Anyways, with the current implementation you can't do
> that, and it is not simple to change (because we may traverse *a lot* of
> commits if base and upstream are far apart or disconnected).

Ah, with my naive view I would have thought that to process the
patch-id of a commit in upstream and compare it, git has the sha1.

>
> Note that "git cherry -v" gives you the subjects so that you can grep
> for those in case they match in your work flow. Same with "git log
> --cherry --oneline" etc..

yes but as you said the subjects must match which is not always the
case (otherwise that would make patch-id unneeded)

Thanks
-- 
Francis

```
